@@ -18,6 +18,8 @@
 ##'                      correspond to an individual response (\code{FALSE}) or a 
 ##'                      mean response
 ##'        (\code{TRUE}).
+##' @param data An optional data frame. This is required if \code{object$data} 
+##'             is \code{NULL}.
 ##' @param lower The lower endpoint of the interval to be searched.
 ##' @param upper The upper endpoint of the interval to be searched.
 ##' @param q1 Optional lower cutoff to be used in forming confidence intervals. 
@@ -39,24 +41,28 @@
 ##'            are used.
 ##' @return An object of class \code{calibrate} containing the following 
 ##'         components:
-##' \describe{
-##'   \item{\code{estimate}}{The estimate of x0.}
-##'   \item{\code{lwr}}{The lower confidence limit for x0.}
-##'   \item{\code{upr}}{The upper confidence limit for x0.}
-##'   \item{\code{se}}{An estimate of the standard error (Wald interval only).}
-##'   \item{\code{interval}}{The method used for calculating \code{lower} and 
-##'                   \code{upper} (only used by \code{print} method).}
+##' \itemize{
+##'   \item \code{estimate} The estimate of x0.
+##'   \item \code{lwr} The lower confidence limit for x0.
+##'   \item \code{upr} The upper confidence limit for x0.
+##'   \item \code{se} An estimate of the standard error (Wald interval only).
+##'   \item \code{interval} The method used for calculating \code{lower} and 
+##'                   \code{upper} (only used by \code{print} method).
 ##' }
 ##' @references
-##' Graybill, F. A., and Iyer, H. K. Regression analysis: Concepts and 
-##' Applications. Belmont, Calif: Duxbury Press, 1994. 
+##' Graybill, F. A., and Iyer, H. K. (1994)
+##' \emph{Regression analysis: Concepts and Applications}. Duxbury Press. 
 ##'
-##' Huet, S., Bouvier, A., Poursat, M-A., and Jolivet, E. Statistical Tools for 
-##' Nonlinear Regression: A Practical Guide with S-PLUS and R Examples. New York: 
-##' Springer, 2004. 
+##' Huet, S., Bouvier, A., Poursat, M-A., and Jolivet, E.  (2004)
+##' \emph{Statistical Tools for Nonlinear Regression: A Practical Guide with S-PLUS and R Examples}. Springer. 
 ##' 
-##' Seber, G. A. F., and Wild, C. J.. Nonlinear regression. New York: Wiley, 
-##' 1989.
+##' Seber, G. A. F., and Wild, C. J. (1989)
+##' \emph{Nonlinear regression}. Wiley.
+##' 
+##' Oman, Samuel D. (1998).
+##' Calibration with Random Slopes.
+##' \emph{Biometrics} \bold{85}(2): 439--449.
+##' doi:10.1093/biomet/85.2.439.
 ##' @examples
 ##' data(Puromycin, package = "datasets")
 ##' Puromycin2 <- Puromycin[Puromycin$state == "treated", ]
@@ -73,82 +79,70 @@ invest <- function(object, ...) {
 ##' @export
 ##' @method invest lm
 invest.lm <- function(object, y0, interval = c("inversion", "Wald", "none"), 
-                      level = 0.95, mean.response = FALSE, lower, upper, 
+                      level = 0.95, mean.response = FALSE, data, lower, upper, 
                       tol = .Machine$double.eps^0.25, maxiter = 1000,  
                       adjust = c("none", "Bonferroni"), k,  ...) {
   
-  ## Extract data, variables, etc.
-#   d <- eval(object$call$data, sys.frame())
-  d <- eval(object$call$data, envir = parent.frame())
+  ## Extract data, variable names, etc.
+  .data  <- if (!missing(data)) data else eval(object$call$data, 
+                                               envir = parent.frame())
+  xname <- intersect(all.vars(formula(object)[[3]]), colnames(.data)) 
   yname <- all.vars(formula(object)[[2]])
-  xname <- intersect(all.vars(formula(object)[[3]]), colnames(d))
-  if (missing(lower)) {
-    lower <- min(d[, xname])
-  }
-  if (missing(upper)) {
-    upper <- max(d[, xname])
-  }
-  interval <- match.arg(interval)
-  alpha <- 1 - level          # significance level
-  eta <- mean(y0)             # mean unknown
-  m <- length(y0)             # number of unknowns 
+  if (length(xname) != 1) stop("Only one independent variable allowed.")
+  if (missing(lower)) lower <- min(.data[, xname])  # lower limit default
+  if (missing(upper)) upper <- max(.data[, xname])  # upper limit default
+  
+  ## Set up for inverse estimation
+  m <- length(y0)  # number of unknowns 
+  if(mean.response && m > 1) stop("Only one mean response value allowed.")
+  eta <- mean(y0)  # mean unknown
   n <- length(resid(object))  # in case of missing values
   p <- length(coef(object))   # number of regression coefficients
-  
-  ## Calculate correct variance
-  ## FIXME: is this the correct variance to use for all univariate linear 
-  ## models? For example, is this the correct variance for a quadratic fit?
-  v1 <- n - p                       # stage I degrees of freedom
-  v2 <- m - 1                       # stage II degrees of freedom
-  u1 <- Sigma(object)^2             # stage I variance estimate
-  u2 <- if (m == 1) 0 else var(y0)  # stage II variance estimate
-  u <- (v1*u1 + v2*u2)/(v1 + v2)    # pooled estimate of variance
-  rat <- u/u1                       # temporary fix 
-  
-  ## Try to catch errors
-  if (length(xname) != 1) {
-    stop("Only one independent variable allowed.")
-  }
-  if (mean.response && m > 1) {
-    stop("Only one mean response value allowed.")
-  }
-  
-  # Adjustment for simultaneous intervals
-  adjust <- match.arg(adjust)
-  w <- if (adjust == "Bonferroni" && m == 1) {
-         qt(1 - alpha/(2 * k), n+m-p-1)
-       } else {
-         qt(1 - alpha/2, n+m-p-1)
-       }
+  df1 <- n - p  # stage 1 degrees of freedom
+  df2 <- m - 1  # stage 2 degrees of freedom
+  var1 <- Sigma(object)^2  # stage 1 variance estimate
+  var2 <- if (m == 1) 0 else var(y0)  # stage 2 variance estimate
+  var.pooled <- (df1*var1 + df2*var2) / (df1 + df2)  # pooled estimate
+  rat <- var.pooled / var1  # right variance?
   
   ## Calculate point estimate by inverting fitted model
   x0.est <- try(uniroot(function(x) {
-      predict(object, newdata = makeData(object, x)) - eta
-    }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root, 
-    silent = TRUE)
-
+    predict(object, newdata = makeData(x, xname)) - eta
+  }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root, 
+  silent = TRUE)
+  
   ## Provide (informative) error message if point estimate is not found
   if (inherits(x0.est, "try-error")) {
-    stop(paste("Point estimate not found in the default interval (", lower, 
+    stop(paste("Point estimate not found in the search interval (", lower, 
                ", ", upper, "). ", 
                "Try tweaking the values of lower and upper. ",
                "Use plotFit for guidance.", sep = ""), 
          call. = FALSE)
   }
-
+  
   ## Return point estimate only
+  interval <- match.arg(interval)
   if (interval == "none") return(x0.est)
-
+  
+  ## Critical value for confidence interval computations
+  adjust <- match.arg(adjust)
+  crit <- if (adjust == "Bonferroni" && m == 1) {
+            qt((level + 2*k - 1) / (2*k), n+m-p-1)  # Bonferroni adjustment
+          } else {
+            qt((level+1) / 2, n+m-p-1)  # no adjustment
+          }
+  
   ## inversion interval --------------------------------------------------------
   if (interval == "inversion") { 
     
     ## Inversion function
     inversionFun <- function(x) {
-      pred <- predict(object, makeData(object, x), se.fit = TRUE)
-      denom <- if (mean.response) pred$se.fit^2 else u/m + rat*pred$se.fit^2
-      (eta - pred$fit)^2/denom - w^2
+      pred <- predict(object, newdata = makeData(x, xname), se.fit = TRUE)
+      denom <- if (mean.response) pred$se.fit^2 else var.pooled/m + 
+        rat*pred$se.fit^2
+      (eta - pred$fit)^2/denom - crit^2
     }
-        
+    
     ## Compute lower and upper confidence limits (i.e., the roots of the 
     ## inversion function)
     lwr <- try(uniroot(inversionFun, interval = c(lower, x0.est), tol = tol, 
@@ -158,14 +152,14 @@ invest.lm <- function(object, y0, interval = c("inversion", "Wald", "none"),
     
     ## Provide (informative) error message if confidence limits not found
     if (inherits(lwr, "try-error")) {
-      stop(paste("Lower confidence limit not found in the default interval (", 
+      stop(paste("Lower confidence limit not found in the search interval (", 
                  lower, ", ", upper, 
                  "). ", "Try tweaking the values of lower and upper. ", 
                  "Use plotFit for guidance.", sep = ""), 
            call. = FALSE)
     }
     if (inherits(upr, "try-error")) {
-      stop(paste("Upper confidence limit not found in the default interval (", 
+      stop(paste("Upper confidence limit not found in the search interval (", 
                  lower, ", ", upper, 
                  "). ", "Try tweaking the values of lower and upper. ", 
                  "Use plotFit for guidance.", sep = ""), 
@@ -178,7 +172,7 @@ invest.lm <- function(object, y0, interval = c("inversion", "Wald", "none"),
                 "upper" = upr, 
                 "interval" = interval)
   } 
-
+  
   ## Wald interval -------------------------------------------------------------
   if (interval == "Wald") { 
     
@@ -193,8 +187,9 @@ invest.lm <- function(object, y0, interval = c("inversion", "Wald", "none"),
         z <- params[length(params)]
       }
       uniroot(function(x) { 
-          predict(object.copy, makeData(object.copy, x)) - z
-        }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root
+#         predict(object.copy, makeData(object.copy, x)) - z
+        predict(object.copy, newdata = makeData(x, xname)) - z
+      }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root
     }
     
     ## Variance-covariane matrix
@@ -204,18 +199,18 @@ invest.lm <- function(object, y0, interval = c("inversion", "Wald", "none"),
     } else {
       params <- c(coef(object), eta)
       covmat <- diag(p + 1)
-      covmat[p + 1, p + 1] <- u/m
+      covmat[p + 1, p + 1] <- var.pooled/m
       covmat[1:p, 1:p] <- vcov(object)
     }
-          
+    
     ## Calculate gradient, and return standard error
     gv <- attr(numericDeriv(quote(dmFun(params)), "params"), "gradient")
     se <- as.numeric(sqrt(gv %*% covmat %*% t(gv)))
-
+    
     ## Store results in a list
     res <- list("estimate" = x0.est, 
-                "lower" = x0.est - se * w, 
-                "upper" = x0.est + se * w, 
+                "lower" = x0.est - crit * se, 
+                "upper" = x0.est + crit * se, 
                 "se" = se,
                 "interval" = interval)
   }
@@ -230,58 +225,54 @@ invest.lm <- function(object, y0, interval = c("inversion", "Wald", "none"),
 ##' @export
 ##' @method invest nls
 invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),  
-                       level = 0.95, mean.response = FALSE, lower, upper, 
-                       tol = .Machine$double.eps^0.25, maxiter = 1000, 
-                       adjust = c("none", "Bonferroni"), k, ...) 
-{
+                       level = 0.95, mean.response = FALSE, data, lower, upper, 
+                       tol = .Machine$double.eps^0.25, maxiter = 1000,
+                       adjust = c("none", "Bonferroni"), k, ...) {
   
-  ## Extract data, variables, etc.
-#   d <- eval(object$call$data, sys.frame())
-  d <- eval(if("data" %in% names(object)) object$data else object$call$data,
-            envir = parent.frame())
+  ## TODO:
+  ##  * Add bootstrap option.
+  
+  ## No support for the Golub-Pereyra algorithm for partially linear 
+  ## least-squares models
+  if (object$call$algorithm == "plinear") {
+    stop(paste("The Golub-Pereyra algorithm for partially linear least-squares 
+               models is currently not supported."))
+  }
+  
+  ## Extract data, variable names, etc.
+  .data  <- if (!missing(data)) data else eval(object$call$data, 
+                                               envir = parent.frame())
+  xname <- intersect(all.vars(formula(object)[[3]]), colnames(.data)) 
   yname <- all.vars(formula(object)[[2]])
-  xname <- intersect(all.vars(formula(object)[[3]]), colnames(d))
-  if (missing(lower)) {
-    lower <- min(d[, xname])
-  }
-  if (missing(upper)) {
-    upper <- max(d[, xname])
-  }
-  interval <- match.arg(interval)
-  alpha <- 1 - level
-  eta <- mean(y0)
-  m <- length(y0)
-  n <- length(resid(object)) 
-  p <- length(coef(object))
+  if (length(xname) != 1) stop("Only one independent variable allowed.")
+  if (missing(lower)) lower <- min(.data[, xname])  # lower limit default
+  if (missing(upper)) upper <- max(.data[, xname])  # upper limit default
   
-  ## Calculate variance
-  u <- Sigma(object)^2
+  ## Set up for inverse estimation
+  m <- length(y0)  # number of unknowns 
+  if(mean.response && m > 1) stop("Only one mean response value allowed.")
+  eta <- mean(y0)  # mean response
+  n <- length(resid(object))  # sample size
+  p <- length(coef(object))  # number of parameters
+  var.pooled <- Sigma(object)^2  # residual variance
   
-  ## Try to catch errors
-  if (length(xname) != 1) {
-    stop("Only one independent variable allowed.")
-  }
-  if(mean.response && m > 1) {
-    stop("Only one value of the mean response is allowed.")
-  }
-  
-  # Adjustment for simultaneous intervals
+  ## Critical value for confidence interval computations
   adjust <- match.arg(adjust)
-  w <- if (adjust == "Bonferroni" && m == 1) {
-         qt(1 - alpha/(2 * k), n+m-p-1)
-       } else {
-         qt(1 - alpha/2, n+m-p-1)
-       }
-  
+  crit <- if (adjust == "Bonferroni" && m == 1) {
+            qt((level + 2*k - 1) / (2*k), n+m-p-1)  # Bonferroni adjustment
+          } else {
+            qt((level + 1) / 2, n+m-p-1)  # no adjustment
+          }
+
   ## Calculate point estimate by inverting fitted model
   x0.est <- try(uniroot(function(x) {
-      predict(object, newdata = makeData(object, x)) - eta
-    }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root, 
-    silent = TRUE)
-
+    predict(object, newdata = makeData(x, xname)) - eta
+  }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root, 
+  silent = TRUE)
+  
   ## Provide (informative) error message if point estimate is not found
   if (inherits(x0.est, "try-error")) {
-    stop(paste("Point estimate not found in the default interval (", lower, 
+    stop(paste("Point estimate not found in the search interval (", lower, 
                ", ", upper, "). ", 
                "Try tweaking the values of lower and upper. ",
                "Use plotFit for guidance.", sep = ""), 
@@ -289,6 +280,7 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
   }
   
   ## Return point estimate only
+  interval <- match.arg(interval)
   if (interval == "none") return(x0.est)
   
   ## Inversion interval --------------------------------------------------------
@@ -296,9 +288,9 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
     
     ## Inversion function
     inversionFun <- function(x) {
-      pred <- predict2(object, makeData(object, x)) # FIXME:, se.fit = TRUE)
-      denom <- if (mean.response) pred$se.fit^2 else (u/m + pred$se.fit^2)
-      (eta - pred$fit)^2/denom - w^2
+      pred <- predict2(object, newdata = makeData(x, xname)) 
+      denom <- if (mean.response) pred$se.fit^2 else (var.pooled/m + pred$se.fit^2)
+      (eta - pred$fit)^2/denom - crit^2
     }
     
     ## Compute lower and upper confidence limits (i.e., the roots of the 
@@ -307,17 +299,17 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
                        maxiter = maxiter)$root, silent = TRUE)
     upr <- try(uniroot(inversionFun, interval = c(x0.est, upper), tol = tol, 
                        maxiter = maxiter)$root, silent = TRUE)
-
+    
     ## Provide (informative) error message if confidence limits not found
     if (inherits(lwr, "try-error")) {
-      stop(paste("Lower confidence limit not found in the default interval (", 
+      stop(paste("Lower confidence limit not found in the search interval (", 
                  lower, ", ", upper, 
                  "). ", "Try tweaking the values of lower and upper. ", 
                  "Use plotFit for guidance.", sep = ""), 
            call. = FALSE)
     }
     if (inherits(upr, "try-error")) {
-      stop(paste("Upper confidence limit not found in the default interval (", 
+      stop(paste("Upper confidence limit not found in the search interval (", 
                  lower, ", ", upper, 
                  "). ", "Try tweaking the values of lower and upper. ", 
                  "Use plotFit for guidance.", sep = ""), 
@@ -345,7 +337,7 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
         z <- params[length(params)]
       }
       uniroot(function(x) { 
-        predict(object.copy, makeData(object.copy, x)) - z
+        predict(object.copy, newdata = makeData(x, xname)) - z
       }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root
     }
     
@@ -356,7 +348,7 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
     } else {
       params <- c(coef(object), eta)
       covmat <- diag(p + 1)
-      covmat[p + 1, p + 1] <- u/m
+      covmat[p + 1, p + 1] <- var.pooled/m
       covmat[1:p, 1:p] <- vcov(object)
     }
     
@@ -366,12 +358,12 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
     
     ## Store results in a list
     res <- list("estimate" = x0.est, 
-                "lower" = x0.est - w * se, 
-                "upper" = x0.est + w * se, 
+                "lower" = x0.est - crit * se, 
+                "upper" = x0.est + crit * se, 
                 "se" = se,
                 "interval" = interval)
   }
-
+  
   ## Assign class label and return results
   class(res) <- "calibrate"
   res
@@ -382,74 +374,63 @@ invest.nls <- function(object, y0, interval = c("inversion", "Wald", "none"),
 ##' @export
 ##' @method invest lme
 invest.lme <- function(object, y0, interval = c("inversion", "Wald", "none"),  
-                       level = 0.95, mean.response = FALSE, lower, upper, q1, 
-                       q2, tol = .Machine$double.eps^0.25, maxiter = 1000, ...) 
+                       level = 0.95, mean.response = FALSE, data, lower, upper, 
+                       q1, q2, tol = .Machine$double.eps^0.25, maxiter = 1000, 
+                       ...) 
 {
   
-  ## Extract data, variables, etc.
-  d <- getData(object) #eval(object$call$data, sys.frame())
+  ## Extract data, variable names, etc.
+  .data  <- if (!missing(data)) data else object$data
+  xname <- intersect(all.vars(formula(object)[[3]]), colnames(.data)) 
   yname <- all.vars(formula(object)[[2]])
-  xname <- intersect(all.vars(formula(object)[[3]]), colnames(d))
-  if (missing(lower)) {
-    lower <- min(d[, xname])
-  }
-  if (missing(upper)) {
-    upper <- max(d[, xname])
-  }
-  interval <- match.arg(interval)
-  alpha <- 1 - level
-  eta <- mean(y0)
+  if (length(xname) != 1) stop("Only one independent variable allowed.")
+  if (missing(lower)) lower <- min(.data[, xname])  # lower limit default
+  if (missing(upper)) upper <- max(.data[, xname])  # upper limit default
+  
+  ## Set up for inverse estimation
+#   if(m > 1) stop("Only one response value allowed.")
   m <- length(y0)
-  if (m != 1) stop('only a single unknown allowed for objects of class "lme"')
+  if(mean.response && m > 1) stop("Only one mean response value allowed.")
+  eta <- mean(y0)
+  if (m != 1) stop('Only a single unknown allowed for objects of class "lme".')
   N <- length(resid(object)) 
   p <- length(fixef(object))
+#   res.var <- Sigma(object)^2  # residual variance
   
-  ## Calculate variance
-  u <- Sigma(object)^2  # residual variance
-  
-  ## Try to catch errors
-  if (length(xname) != 1) {
-    stop("Only one independent variable allowed.")
-  }
-  if(mean.response && m > 1) {
-    stop("Only one value of the mean response is allowed.")
-  }
-  
-  # Critical value. Oman (1998. pg. 445) suggests a t(1-alpha/2, N-1) dist.
-  if (missing(q1) && missing(q2)) {
-    q1 <- qnorm(alpha/2)
-    q2 <- qnorm(1 - alpha/2)
-  }
+  ## Critical value. Oman (1998. pg. 445) suggests a t(1-alpha/2, N-1) dist.
+  if (missing(q1)) q1 <- qnorm((1-level) / 2)
+  if (missing(q2)) q2 <- qnorm((1+level) / 2)
   
   ## Calculate point estimate by inverting fitted model
   x0.est <- try(uniroot(function(x) {
-    predict(object, newdata = makeData(object, x), level = 0) - eta
+    predict(object, newdata = makeData(x, xname), level = 0) - eta
   }, interval = c(lower, upper), tol = tol, maxiter = maxiter)$root, 
   silent = TRUE)
   
   ## Provide (informative) error message if point estimate is not found
   if (inherits(x0.est, "try-error")) {
-    stop(paste("Point estimate not found in the default interval (", lower, 
+    stop(paste("Point estimate not found in the search interval (", lower, 
                ", ", upper, "). ", 
-               "Try tweaking the values of lower and upper. ",
-               "Use plotFit for guidance.", sep = ""), 
+               "Try tweaking the values of lower and upper.", 
+               sep = ""), 
          call. = FALSE)
   }
   
   ## Return point estimate only
+  interval <- match.arg(interval)
   if (interval == "none") return(x0.est)
   
   ## Estimate variance of new response
-  if (!mean.response) var.y0 <- varY(object, makeData(object, x0.est))
+  if (!mean.response) var.y0 <- varY(object, newdata = makeData(x0.est, xname))
   
   ## Inversion interval --------------------------------------------------------
   if (interval == "inversion") { 
     
     ## Inversion function
     inversionFun <- function(x, bound = c("lower", "upper")) {
-      bound <- match.arg(bound)
-      pred <- predict2(object, makeData(object, x), se.fit = TRUE)
+      pred <- predict2(object, newdata = makeData(x, xname), se.fit = TRUE)
       denom <- if (mean.response) pred$se.fit else sqrt(var.y0 + pred$se.fit^2)
+      bound <- match.arg(bound)
       if (bound == "upper") {
         (eta - pred$fit)/denom - q1
       } else {
@@ -468,17 +449,17 @@ invest.lme <- function(object, y0, interval = c("inversion", "Wald", "none"),
     
     ## Provide (informative) error message if confidence limits not found
     if (inherits(lwr, "try-error")) {
-      stop(paste("Lower confidence limit not found in the default interval (", 
+      stop(paste("Lower confidence limit not found in the search interval (", 
                  lower, ", ", upper, 
-                 "). ", "Try tweaking the values of lower and upper. ", 
-                 "Use plotFit for guidance.", sep = ""), 
+                 "). ", "Try tweaking the values of lower and upper.", 
+                 sep = ""), 
            call. = FALSE)
     }
     if (inherits(upr, "try-error")) {
-      stop(paste("Upper confidence limit not found in the default interval (", 
+      stop(paste("Upper confidence limit not found in the search interval (", 
                  lower, ", ", upper, 
-                 "). ", "Try tweaking the values of lower and upper. ", 
-                 "Use plotFit for guidance.", sep = ""), 
+                 "). ", "Try tweaking the values of lower and upper.",
+                 sep = ""), 
            call. = FALSE)
     }
     
@@ -497,7 +478,7 @@ invest.lme <- function(object, y0, interval = c("inversion", "Wald", "none"),
     dmFun <- function(params) {
       fun <- function(x) {
         X <- model.matrix(eval(object$call$fixed)[-2], 
-                          data = makeData(object, x))
+                          data = makeData(x, xname))
         if (mean.response) {
           X %*% params - eta
         } else {
@@ -525,8 +506,8 @@ invest.lme <- function(object, y0, interval = c("inversion", "Wald", "none"),
     
     ## Store results in a list
     res <- list("estimate" = x0.est, 
-                "lower" = x0.est - q2*se, 
-                "upper" = x0.est + q2*se,
+                "lower" = x0.est - q2 * se, 
+                "upper" = x0.est + q2 * se,
                 "se" = se,
                 "interval" = interval)
     
@@ -536,4 +517,4 @@ invest.lme <- function(object, y0, interval = c("inversion", "Wald", "none"),
   class(res) <- "calibrate"
   res
   
-}
\ No newline at end of file
+}
